@@ -2,4 +2,6 @@ __version__='0.0.1'
 
 from capslock.decorators import timing
 from capslock.decorators import debug
-from capslock.decorators import run_multiple_times
\ No newline at end of file
+from capslock.decorators import run_multiple_times
+from capslock.decorators import require_root
+from capslock.decorators import color_output
\ No newline at end of file
